@@ -7,51 +7,61 @@ use serde::Deserialize;
 use smart_default::SmartDefault;
 use umbra::optional;
 
-use crate::keybind::KeyBind;
+use crate::{keybind::KeyBind, Result};
 
+const XDG_CONFIG_HOME_ENV_NAME: &str = "XDG_CONFIG_HOME";
+const DEFAULT_CONFIG_DIR: &str = ".config";
 const APP_DIR_NAME: &str = "serie";
 const CONFIG_FILE_NAME: &str = "config.toml";
 const CONFIG_FILE_ENV_NAME: &str = "SERIE_CONFIG_FILE";
 
-pub fn load() -> (UiConfig, GraphConfig, Option<KeyBind>) {
+pub fn load() -> Result<(CoreConfig, UiConfig, GraphConfig, Option<KeyBind>)> {
     let config = match config_file_path_from_env() {
         Some(user_path) => {
             if !user_path.exists() {
-                panic!("Config file not found: {:?}", user_path);
+                let msg = format!("Config file not found: {user_path:?}");
+                return Err(msg.into());
             }
             read_config_from_path(&user_path)
         }
         None => {
-            let default_path = xdg_config_file_path();
-            if default_path.exists() {
-                read_config_from_path(&default_path)
+            if let Some(default_path) = config_file_path() {
+                if default_path.exists() {
+                    read_config_from_path(&default_path)
+                } else {
+                    Ok(Config::default())
+                }
             } else {
-                Config::default()
+                Ok(Config::default())
             }
         }
-    };
-    (config.ui, config.graph, config.keybind)
+    }?;
+    Ok((config.core, config.ui, config.graph, config.keybind))
 }
 
 fn config_file_path_from_env() -> Option<PathBuf> {
     env::var(CONFIG_FILE_ENV_NAME).ok().map(PathBuf::from)
 }
 
-fn xdg_config_file_path() -> PathBuf {
-    xdg::BaseDirectories::with_prefix(APP_DIR_NAME)
-        .unwrap()
-        .get_config_file(CONFIG_FILE_NAME)
+fn config_file_path() -> Option<PathBuf> {
+    env::var(XDG_CONFIG_HOME_ENV_NAME)
+        .ok()
+        .map(PathBuf::from)
+        .or_else(|| env::home_dir().map(|home| home.join(DEFAULT_CONFIG_DIR)))
+        .map(|config_dir| config_dir.join(APP_DIR_NAME).join(CONFIG_FILE_NAME))
 }
 
-fn read_config_from_path(path: &Path) -> Config {
-    let content = std::fs::read_to_string(path).unwrap();
-    let config: OptionalConfig = toml::from_str(&content).unwrap();
-    config.into()
+fn read_config_from_path(path: &Path) -> Result<Config> {
+    let content = std::fs::read_to_string(path)?;
+    let config: OptionalConfig = toml::from_str(&content)?;
+    Ok(config.into())
 }
 
 #[optional(derives = [Deserialize])]
 #[derive(Debug, Default, Clone, PartialEq, Eq)]
 struct Config {
+    #[nested]
+    core: CoreConfig,
     #[nested]
     ui: UiConfig,
     #[nested]
@@ -60,6 +70,22 @@ struct Config {
     keybind: Option<KeyBind>,
 }
 
+#[optional(derives = [Deserialize])]
+#[derive(Debug, Default, Clone, PartialEq, Eq)]
+pub struct CoreConfig {
+    #[nested]
+    pub search: CoreSearchConfig,
+}
+
+#[optional(derives = [Deserialize])]
+#[derive(Debug, Clone, PartialEq, Eq, SmartDefault)]
+pub struct CoreSearchConfig {
+    #[default = false]
+    pub ignore_case: bool,
+    #[default = false]
+    pub fuzzy: bool,
+}
+
 #[optional(derives = [Deserialize])]
 #[derive(Debug, Default, Clone, PartialEq, Eq)]
 pub struct UiConfig {
@@ -152,6 +178,12 @@ mod tests {
     fn test_config_default() {
         let actual = Config::default();
         let expected = Config {
+            core: CoreConfig {
+                search: CoreSearchConfig {
+                    ignore_case: false,
+                    fuzzy: false,
+                },
+            },
             ui: UiConfig {
                 common: UiCommonConfig {
                     cursor_type: CursorType::Native,
@@ -192,6 +224,9 @@ mod tests {
     #[test]
     fn test_config_complete_toml() {
         let toml = r##"
+            [core.search]
+            ignore_case = true
+            fuzzy = true
             [ui.common]
             cursor_type = { Virtual = "|" }
             [ui.list]
@@ -213,6 +248,12 @@ mod tests {
         "##;
         let actual: Config = toml::from_str::<OptionalConfig>(toml).unwrap().into();
         let expected = Config {
+            core: CoreConfig {
+                search: CoreSearchConfig {
+                    ignore_case: true,
+                    fuzzy: true,
+                },
+            },
             ui: UiConfig {
                 common: UiCommonConfig {
                     cursor_type: CursorType::Virtual("|".into()),
@@ -251,6 +292,12 @@ mod tests {
         "#;
         let actual: Config = toml::from_str::<OptionalConfig>(toml).unwrap().into();
         let expected = Config {
+            core: CoreConfig {
+                search: CoreSearchConfig {
+                    ignore_case: false,
+                    fuzzy: false,
+                },
+            },
             ui: UiConfig {
                 common: UiCommonConfig {
                     cursor_type: CursorType::Native,
